package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DistributedCacheServicesMapper;
import com.zyc.system.domain.DistributedCacheServices;
import com.zyc.system.service.IDistributedCacheServicesService;

/**
 * 分布式缓存服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DistributedCacheServicesServiceImpl implements IDistributedCacheServicesService 
{
    @Autowired
    private DistributedCacheServicesMapper distributedCacheServicesMapper;

    /**
     * 查询分布式缓存服务
     * 
     * @param id 分布式缓存服务主键
     * @return 分布式缓存服务
     */
    @Override
    public DistributedCacheServices selectDistributedCacheServicesById(Integer id)
    {
        return distributedCacheServicesMapper.selectDistributedCacheServicesById(id);
    }

    /**
     * 查询分布式缓存服务列表
     * 
     * @param distributedCacheServices 分布式缓存服务
     * @return 分布式缓存服务
     */
    @Override
    public List<DistributedCacheServices> selectDistributedCacheServicesList(DistributedCacheServices distributedCacheServices)
    {
        return distributedCacheServicesMapper.selectDistributedCacheServicesList(distributedCacheServices);
    }

    /**
     * 新增分布式缓存服务
     * 
     * @param distributedCacheServices 分布式缓存服务
     * @return 结果
     */
    @Override
    public int insertDistributedCacheServices(DistributedCacheServices distributedCacheServices)
    {
        return distributedCacheServicesMapper.insertDistributedCacheServices(distributedCacheServices);
    }

    /**
     * 修改分布式缓存服务
     * 
     * @param distributedCacheServices 分布式缓存服务
     * @return 结果
     */
    @Override
    public int updateDistributedCacheServices(DistributedCacheServices distributedCacheServices)
    {
        return distributedCacheServicesMapper.updateDistributedCacheServices(distributedCacheServices);
    }

    /**
     * 批量删除分布式缓存服务
     * 
     * @param ids 需要删除的分布式缓存服务主键
     * @return 结果
     */
    @Override
    public int deleteDistributedCacheServicesByIds(Integer[] ids)
    {
        return distributedCacheServicesMapper.deleteDistributedCacheServicesByIds(ids);
    }

    /**
     * 删除分布式缓存服务信息
     * 
     * @param id 分布式缓存服务主键
     * @return 结果
     */
    @Override
    public int deleteDistributedCacheServicesById(Integer id)
    {
        return distributedCacheServicesMapper.deleteDistributedCacheServicesById(id);
    }
}
